// $Id: ColorModel.cpp,v 1.19 2013/02/14 09:02:48 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "CustomPixmap.h"
#include "ColorModel.h"
#include "IconSize.h"
#include "TimeStamp.h"
#include "XmlOptions.h"

#include <QApplication>
#include <QIcon>
#include <QLinearGradient>
#include <QPainter>
#include <QWidget>

//_____________________________________________________________
bool operator < (const QColor& first, const QColor& second )
{ return first.name() < second.name(); }

//_______________________________________________
ColorModel::IconCache& ColorModel::_icons( void )
{
    static IconCache singleton;
    return singleton;
}

//_______________________________________________
const QString ColorModel::columnTitles_[ ColorModel::nColumns ] =
{ "Color Name" };

//__________________________________________________________________
QVariant ColorModel::data( const QModelIndex& index, int role ) const
{
    Debug::Throw( "ColorModel::data.\n" );

    // check index, role and column
    if( !index.isValid() ) return QVariant();

    // retrieve associated color
    const QColor& color( get()[index.row()] );

    // return text associated to file and column
    if( role == Qt::DisplayRole && index.column() == COLOR ) return color.name();

    // return icon associated to file
    if( role == Qt::DecorationRole && index.column() == COLOR ) return _icon( color );

    return QVariant();

}

//__________________________________________________________________
QVariant ColorModel::headerData(int section, Qt::Orientation orientation, int role) const
{

    if(
        orientation == Qt::Horizontal &&
        role == Qt::DisplayRole &&
        section >= 0 &&
        section < nColumns )
    { return columnTitles_[section]; }

    // return empty
    return QVariant();

}

//____________________________________________________________
void ColorModel::_sort( int column, Qt::SortOrder order )
{
    Debug::Throw() << "ColorModel::sort - column: " << column << " order: " << order << endl;
    std::sort( _get().begin(), _get().end(), SortFTor( (ColumnType) column, order ) );
}

//________________________________________________________
bool ColorModel::SortFTor::operator () ( QColor first, QColor second ) const
{

    if( order_ == Qt::DescendingOrder ) std::swap( first, second );

    switch( type_ )
    {

        case COLOR:
        { return first.name() < second.name(); }
        break;

        default: return true;
    }

}

//______________________________________________________
QIcon ColorModel::_icon( const QColor& color )
{

    IconCache::iterator iter( _icons().find( color.name() ) );
    if( iter != _icons().end() ) return iter.value();
    else {

        QPixmap pixmap( CustomPixmap().empty( IconSize( IconSize::Large ) ) );
        QPainter painter( &pixmap );
        painter.setPen( Qt::black );
        painter.setBrush( color );
        painter.setRenderHints(QPainter::Antialiasing );

        QRect rect( pixmap.rect() );
        rect.adjust( 2, 2, -2, -2 );

        painter.drawEllipse( rect );

        QIcon icon( pixmap );
        _icons()[color.name()] = icon;
        return icon;

    }

}
