#ifndef ColorSelectionFrame_h
#define ColorSelectionFrame_h

// $Id: ColorSelectionFrame.h,v 1.25 2013/02/22 12:05:49 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Counter.h"
#include "Debug.h"

#include <QLabel>
#include <QLayout>
#include <QPainter>
#include <QPushButton>
#include <QSpinBox>
#include <QGroupBox>
#include <QHash>

class AnimatedLineEditor;
class TransitionWidget;


namespace PRIVATE
{
    class ColorWidget;
    class ColorDisplay;
};

//class ColorSelectionFrame:public QGroupBox, public Counter
class ColorSelectionFrame:public QWidget, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! creator
    ColorSelectionFrame( QWidget* parent );

    //! destructor
    ~ColorSelectionFrame( void )
    { Debug::Throw() << "ColorSelectionFrame::~ColorSelectionFrame.\n"; }

    //! retrieve selected color
    const QColor& color( void ) const
    { return color_; }

    //! save action
    QAction& saveAction( void ) const
    { return *saveAction_; }

    //! color widget
    QAbstractButton& colorWidget( void ) const;

    public slots:

    //! sets selected color
    void setColor( QString );

    //! sets selected color
    void setColor( const QRgb& );

    private slots:

    //! update color from editor
    void _fromEditor( const QString& );

    //! update color from HSV editors
    void _fromHsv( void );

    //! update color from RGB editors
    void _fromRgb( void );

    private:

    //! update label
    void _updateLabel( void );

    //! install actions
    void _installActions( void );

    //! line editor id enumeration
    enum SpinBoxId
    {
        HUE,
        SATURATION,
        VALUE,
        RED,
        GREEN,
        BLUE,
        ALPHA
    };

    //! internal line Editor to have matching ID
    class SpinBox: public QSpinBox
    {

        public:

        //! constructor
        SpinBox( QWidget* parent, SpinBoxId id ):
            QSpinBox( parent ),
            id_( id )
        {}

        //! button ID
        SpinBoxId id( void ) const
        { return id_; }

        private:

        //! button ID
        SpinBoxId id_;

    };

    //! true when values are being updated
    /*! it is used to disable the callbacks when updating from one spinbox */
    bool locked_;

    //! color widget
    PRIVATE::ColorWidget* colorWidget_;

    //! color display
    PRIVATE::ColorDisplay* colorDisplay_;

    //! the label where color and colorname are display
    AnimatedLineEditor* editor_;

    //! save action
    QAction* saveAction_;

    //! transition widget
    TransitionWidget* transitionWidget_;

    //! Editor map
    typedef QHash< SpinBoxId, SpinBox* > SpinBoxMap;

    //! Editor map
    SpinBoxMap spinboxes_;

    //! current selected color
    QColor color_;

};

#endif
