#ifndef MainWindow_h
#define MainWindow_h

// $Id: MainWindow.h,v 1.20 2013/02/22 12:05:50 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Counter.h"
#include "ColorList.h"
#include "ColorSelectionFrame.h"
#include "BaseMainWindow.h"
#include "Debug.h"

#include <QPushButton>
#include <QWidget>
#include <QCloseEvent>

class Menu;

//! color picker dialog
class MainWindow: public BaseMainWindow
{

    Q_OBJECT

    public:

    //! constructor
    MainWindow( QWidget* = 0);

    //! destructor
    virtual ~MainWindow( void )
    {}

    //! retrieve colorselection frame
    const QColor& color( void ) const
    { return selectionFrame_->color(); }

    //! toggle list
    QAction& toggleListAction( void ) const
    { return *toggleListAction_; }

    protected:

    //! close event
    virtual void closeEvent( QCloseEvent* event );

    private slots:

    //! update configuration
    void _updateConfiguration( void );

    //! load colors from file
    void _read( void );

    //! write colors to file
    void _write( void );

    //! add current color in list
    void _add( void );

    //! select color from list
    void _selectFromList( const QModelIndex & );

    //! show/hide recent colors
    void _toggleShowList( bool );

    private:

    //! install actions
    void _installActions( void );

    //! menu
    Menu* menu_;

    //! color list
    ColorList* list_;

    //! frame to display current color
    ColorSelectionFrame* selectionFrame_;

    //@name actions
    //@{

    //! toggle list
    QAction* toggleListAction_;

    //@}

};

#endif
